GaussianDust — so_pysm_models v0.4.dev210

so_pysm_models:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- so_pysm_models v0.4.dev210 »
- GaussianDust

# GaussianDust

class `so_pysm_models.` `GaussianDust`(target_nside, has_polarization=True, pixel_indices=None, TT_amplitude=350.0, Toffset=18.0, EE_amplitude=100.0, rTE=0.35, EtoB=0.5, alpha=-0.42, beta=1.53, temp=19.6, nu_0=353, seed=None)

  Bases: `object`

  Gaussian dust model

  See more details at https://so-pysm-models.readthedocs.io/en/latest/so_pysm_models/models.html

  Parameters: | target_nside : int HEALPix NSIDE of the output maps has_polarization : bool whether or not to simulate also polarization maps Default: True pixel_indices : ndarray of ints Outputs partial maps given HEALPix pixel indices in RING ordering TT_amplitude : float amplitude of synchrotron TT power spectrum (D_ell) at at the reference frequency and ell=80, in muK^2 and thermodinamic units. Default: 350. from the amplitude of PySM-d0 dust model at 353GHz in the region covered by SO-SAT. Toffset : float offset to be applied to the temperature map in muK in RJ units. Default: 18 from the mean value of the T PySM-s0 synch map at 23GHz in the region covered by SO-SAT EE_amplitude : float Amplitude of EE modes D_ell at reference frequency at ell=80 Default: 100. from the amplitude of HFI-353 E-modes spectrum in the region covered by SO-SAT EtoB: float ratio between E and B-mode amplitude for dust. Default: 0.5 from Planck 2018 IX alpha : same as alpha_sync for dust. Default: -0.42 from Planck 2018 IX beta : float dust spectral index. Default: 1.53 from Planck 2018 IX temp : float dust temperature. Default: 19.6 from Planck 2018 IX nu0 : float dust reference frequency in GHz. Default: 353 seed : int seed for random realization of map Default: None

  Methods Summary

  `signal`(nu, **kwargs) | Return map in uK_RJ at given frequency or array of frequencies

  Methods Documentation

  `signal`(nu, **kwargs)

    Return map in uK_RJ at given frequency or array of frequencies